More debugger support.

This wires up method-entry events and fixes a bug in exception events.

Change-Id: Ia7c46786a8073434fbb4546615072622f301ef84
diff --git a/src/runtime_support.cc b/src/runtime_support.cc
index eb06df5..670049a 100644
--- a/src/runtime_support.cc
+++ b/src/runtime_support.cc
@@ -16,6 +16,7 @@
 
 #include "runtime_support.h"
 
+#include "debugger.h"
 #include "dex_cache.h"
 #include "dex_verifier.h"
 #include "macros.h"
@@ -100,14 +101,14 @@
 }
 
 /*
  * Report location to debugger.  Note: dalvikPC is the current offset within
  * the method.  However, because the offset alone cannot distinguish between
  * method entry and offset 0 within the method, we'll use an offset of -1
  * to denote method entry.
  */
-extern "C" void artUpdateDebuggerFromCode(int32_t dalvikPC, Thread* self, Method** sp) {
+extern "C" void artUpdateDebuggerFromCode(int32_t dex_pc, Thread* self, Method** sp) {
   FinishCalleeSaveFrameSetup(self, sp,  Runtime::kRefsAndArgs);
-    // TODO: fill this out similar to old "updateDebugger"
+  Dbg::UpdateDebugger(dex_pc, self, sp);
 }
 
 // Temporary debugging hook for compiler.
@@ -100,14 +101,14 @@
 
 /*
- * Report location to debugger.  Note: dalvikPC is the current offset within
+ * Report location to debugger.  Note: dex_pc is the current offset within
  * the method.  However, because the offset alone cannot distinguish between
  * method entry and offset 0 within the method, we'll use an offset of -1